@@ -293,6 +293,14 @@ LIQ_EXPORT int liq_get_max_colors(liq_attr *attr)
     return attr->max_colors;
 }
 
+LIQ_EXPORT liq_error liq_get_max_colors_2(liq_attr *attr, int * max_colors)
+{
+    if (!CHECK_STRUCT_TYPE(attr, liq_attr)) return LIQ_INVALID_POINTER;
+
+    * max_colors = attr->max_colors;
+    return LIQ_OK;
+}
+
 LIQ_EXPORT liq_error liq_set_min_posterization(liq_attr *attr, int bits)
 {
     if (!CHECK_STRUCT_TYPE(attr, liq_attr)) return LIQ_INVALID_POINTER;
@@ -309,6 +317,14 @@ LIQ_EXPORT int liq_get_min_posterization(liq_attr *attr)
     return attr->min_posterization_output;
 }
 
+LIQ_EXPORT liq_error liq_get_min_posterization_2(liq_attr *attr, int *bits)
+{
+    if (!CHECK_STRUCT_TYPE(attr, liq_attr)) return LIQ_INVALID_POINTER;
+    *bits = attr->min_posterization_output;
+    return LIQ_OK;
+}
+
+
 LIQ_EXPORT liq_error liq_set_speed(liq_attr* attr, int speed)
 {
     if (!CHECK_STRUCT_TYPE(attr, liq_attr)) return LIQ_INVALID_POINTER;
@@ -335,6 +351,13 @@ LIQ_EXPORT int liq_get_speed(liq_attr *attr)
     return attr->speed;
 }
 
+LIQ_EXPORT liq_error liq_get_speed_2(liq_attr *attr, int *speed)
+{
+    if (!CHECK_STRUCT_TYPE(attr, liq_attr)) return LIQ_INVALID_POINTER;
+    *speed = attr->speed;
+    return LIQ_OK;
+}
+
 LIQ_EXPORT liq_error liq_set_output_gamma(liq_result* res, double gamma)
 {
     if (!CHECK_STRUCT_TYPE(res, liq_result)) return LIQ_INVALID_POINTER;
@@ -365,6 +388,14 @@ LIQ_EXPORT int liq_get_min_opacity(liq_attr *attr)
     return MIN(255, 256.0 * attr->min_opaque_val);
 }
 
+LIQ_EXPORT liq_error liq_get_min_opacity_2(liq_attr *attr, int *min)
+{
+    if (!CHECK_STRUCT_TYPE(attr, liq_attr)) return LIQ_INVALID_POINTER;
+    *min = MIN(255, 256.0 * attr->min_opaque_val);
+    return LIQ_OK;
+}
+
+
 LIQ_EXPORT void liq_set_last_index_transparent(liq_attr* attr, int is_last)
 {
     if (!CHECK_STRUCT_TYPE(attr, liq_attr)) return;
